# South Carolina
We do not model the following components of the South Carolina SC1040 2023 Individual Income Tax Return
- line 19, Nonresident sale of real estate (paid on form I-290)
- All credits under line 22
    - line 22a, Anhydrous Ammonia (form I-333)
    - line 22b, Milk credit (form I-334)
    - line 22c, Classroom Teacher Expenses (form I-360)
